@@ -1,18 +1,24 @@
 from . import engine
+from .templates.mysql import template_engine
 
 
 def is_exist(conn, database):
-    result = engine.select_one(conn, 'SHOW DATABASES LIKE :database', {'database': database})
+    sql = template_engine.render('mysql_check_database_exists')
+    result = engine.select_one(conn, sql, {'database_name': database})
     return result is not None
 
 
 def create(conn, database, charset='utf8mb4', collation='utf8mb4_unicode_ci'):
-    sql = f'CREATE DATABASE {database} DEFAULT CHARACTER SET {charset} COLLATE {collation}'
+    sql = template_engine.render(
+        'mysql_create_database',
+        database_name=database,
+        charset=charset,
+        collation=collation)
     engine.execute(conn, sql)
 
 
 def drop(conn, database):
-    sql = f'DROP DATABASE {database}'
+    sql = template_engine.render('mysql_drop_database', database_name=database)
     engine.execute(conn, sql)
 
 
